hotspot/src/share/vm/runtime/vm_operations.cpp
changeset 32401 cc58aeaec340
parent 31620 53be635ad49c
child 33160 c59f1676d27e
child 33148 68fa8b6c4340
--- a/hotspot/src/share/vm/runtime/vm_operations.cpp	Fri Aug 21 09:12:42 2015 +0200
+++ b/hotspot/src/share/vm/runtime/vm_operations.cpp	Tue Aug 25 07:49:55 2015 +0200
@@ -109,8 +109,8 @@
   // Deoptimize all activations depending on marked nmethods
   Deoptimization::deoptimize_dependents();
 
-  // Make the dependent methods zombies
-  CodeCache::make_marked_nmethods_zombies();
+  // Make the dependent methods not entrant
+  CodeCache::make_marked_nmethods_not_entrant();
 }
 
 void VM_MarkActiveNMethods::doit() {